Learn R Programming

googlesheets4 (version 0.0.0.9001)

sheets_email: Get email of current user

Description

Reveals email associated with the Google credential currently being used by googlesheets4 (if there is one). This is semi experimental, inspired by googledrive::drive_user(). The fate of this function to be determined by how scopes shake out and whether we create a way for googledrive and googlesheets4 to share a token.

Usage

sheets_email()

Arguments

Value

An email address or NULL.

Examples

Run this code
# NOT RUN {
sheets_email()
# }

Run the code above in your browser using DataLab